#
# spec file for package git-cola
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Marcin Bajor
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           git-cola
Version:        2.7
Release:        3.2
Summary:        Sleek and powerful git GUI
License:        GPL-2.0+
Group:          Development/Tools/Version Control
Url:            http://git-cola.github.io/

%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

Source:         https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  git-core
BuildRequires:  python
BuildRequires:  python-devel
BuildRequires:  python-pyinotify
BuildRequires:  python-qt4
BuildRequires:  update-desktop-files
Requires:       git-core
Requires:       python-qt4
Recommends:     python-pyinotify
Recommends:     gitk
Recommends:     python-send2trash

%py_requires
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description
git-cola is a simple, powerful, and feature-rich GUI for git
that provides an easy way to interact with Git repositories.

%prep
%setup -q

%build

%install
%makeinstall prefix=%{_prefix} DESTDIR=%{buildroot}
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/git-cola.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/git-dag.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/git-cola-folder-handler.desktop

%find_lang %{name}

%files -f %{name}.lang
%defattr(-,root,root)
%{_bindir}/cola
%{_bindir}/git-cola
%{_bindir}/git-dag
%dir %{_datadir}/git-cola
%{_datadir}/git-cola/*
%{_datadir}/applications/git-cola.desktop
%{_datadir}/applications/git-dag.desktop
%{_datadir}/applications/git-cola-folder-handler.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/git-cola.svg
%dir %{_datadir}/doc/git-cola
%{_datadir}/doc/git-cola/*
%if 0%{?sles_version} > 9
%{_datadir}/locale/zh_cn
%endif

%changelog
* Thu Aug  4 2016 marcin.bajor@gmail.com
- Fixed: git-cola can not find python-qt
* Sun Jul 31 2016 marcin.bajor@gmail.com
- Update to 2.7
- Fixes
  * When repositories stored in non-ASCII, UTF-8-encoded filesystem paths were operated upon with LC_ALL=C set in the environment, unicode errors would occur when using python2. git cola was made more robust and will now operate correctly within this environment.
  https://github.com/git-cola/git-cola/issues/581
  * Support for the GIT_WORK_TREE environment variable was fixed.
  https://github.com/git-cola/git-cola/pull/582
- Development
  * The unittest.mock module is now used instead of the original mock module when running the git cola test suite using Python3.
  https://github.com/git-cola/git-cola/issues/569
- Packaging
  * git cola is now compatible with PyQt5, PyQt4, and Pyside. git cola previously supported PyQt4 only, but will now use whichever library is available. Users are not required to upgrade at this time, but PyQt5 support can be enabled anytime by making its python modules available.
  https://github.com/git-cola/git-cola/issues/232
  NOTE: We do not yet recommend using PyQt5 because there are known exit-on-segfault bugs in Qt5 that have not yet been addressed. git cola is sensitive to this bug and is known to crash on exit when using git dag or the interactive rebase feature on PyQt5.
  https://bugreports.qt.io/browse/QTBUG-52988
  * PyQt4 is stable and there are no known issues when using it so we recommend using it until the Qt5 bugs have been resolved.
  git cola now depends on QtPy and includes a bundled copy of the qtpy library. If you are packaging git cola and would prefer to use qtpy from your distribution instead of the built-in version then use make NO_VENDOR_LIBS=1 when building git cola. This will prevent vendored libraries from being installed.
* Sun May  1 2016 marcin.bajor@gmail.com
- Update to 2.6
- Usability, bells and whistles
  * A new “Reset” sub-menu provides access to running “git reset –mixed” when resetting branch heads and “git reset –merge” when resetting worktrees.
  https://github.com/git-cola/git-cola/issues/542
  * git cola now supports linked worktrees, i.e. worktrees created by git worktree.
  https://github.com/git-cola/git-cola/issues/554
- Fixes
  * Diff highlighting is now robust to the user having diff.supressBlankEmpty=true in their git config.
  https://github.com/git-cola/git-cola/issues/541
  * The filesystem monitor now properly handles repositories that use .git-files, e.g. when using submodules.
  https://github.com/git-cola/git-cola/issues/545
  https://github.com/git-cola/git-cola/pulls/546
  * Per-repository git configuration is now properly detected when launching git cola from an application launcher.
  https://github.com/git-cola/git-cola/issues/548
  * git cola now cleans up after itself immediately to avoid leaving behind empty /tmp/git-cola-XXXXXX directories when the user uses Ctrl+C to quit the app.
  https://github.com/git-cola/git-cola/issues/566
- Packaging
  * It is now possible to install git cola to and from utf8-encoded filesystem paths. Previously, Python’s stdlib would during installation.
  https://github.com/git-cola/git-cola/issues/551
* Sun Jan  3 2016 marcin.bajor@gmail.com
- Update to 2.5
- Usability, bells and whistles
  * The icon for untracked files was adjusted to better differentiate between files and the “Untracked” header.
  https://github.com/git-cola/git-cola/issues/509
  * Ctrl+O was added as a hotkey for opening repositories.
  https://github.com/git-cola/git-cola/pull/507
  * git dag now uses consistent edge colors across updates.
  https://github.com/git-cola/git-cola/issues/512
  * git cola‘s Bookmarks widget can now be used to set a “Default Repository”. Under the hood, we set the cola.defaultrepo configuration variable. The default repository is used whenever git cola is launched outside of a Git repostiory. When unset, or when set to a bogus value, git cola will prompt for a repository, as it previously did.
  https://github.com/git-cola/git-cola/issues/513
  * git cola‘s Russian and Spanish translations were improved thanks to Vaiz and Zeioth.
  https://github.com/git-cola/git-cola/pull/514
  https://github.com/git-cola/git-cola/pull/515
  https://github.com/git-cola/git-cola/pull/523
  * git cola was translated to Turkish thanks to Barış ÇELİK.
  https://github.com/git-cola/git-cola/pull/520
  * The status view now supports launching git gui blame. It can be configured to use a different command by setting cola.blameviewer.
  https://github.com/git-cola/git-cola/pull/521
  * git dag now allows selecting non-contiguous ranges in the log widget.
  https://github.com/git-cola/git-cola/issues/468
  * Any font can now be chosen for the diff editor, not just monospace fonts.
  https://github.com/git-cola/git-cola/issues/525
- Fixes
  * xfce4-terminal and gnome-terminal are now supported when launching git mergetool to resolve merges. These terminals require that the command to execute is shell-quoted and passed as a single string argument to -e rather than as additional command line arguments.
  https://github.com/git-cola/git-cola/issues/524
  * Fixed a unicode problem when formatting the error message that is shown when gitk is not installed. We now handle unicode data in tracebacks generated by python itself.
  https://github.com/git-cola/git-cola/issues/528
  * The New repository feature was fixed.
  https://github.com/git-cola/git-cola/pull/533
  * We now use omit the extended description when creating “fixup!” commits, for consistency with the Git CLI. We now include only the one-line summary in the final commit message.
  https://github.com/git-cola/git-cola/issues/522
* Tue Oct 13 2015 marcin.bajor@gmail.com
- Update to 2.4
- Usability, bells and whistles
  * The user interface is now HiDPI-capable. git-cola now uses SVG icons, and its interface can be scaled by setting the GIT_COLA_SCALE environment variable.
  git dag now supports the standard editor, difftool, and history hotkeys. It is now possible to invoke these actions from file widget’s context menu and through the standard hotkeys.
  https://github.com/git-cola/git-cola/pull/473
- The Status tool also learned about the history hotkey. Additionally, the Alt-{j,k} aliases are also supported in the Status tool for consistency with the other tools where the non-Alt hotkeys are not available.
  https://github.com/git-cola/git-cola/pull/488
  * The File Browser tool now has better default column sizes, and remembers its window size and placement.
  * The File Browser now supports the refresh hotkey, and has better behavior when refreshing. The selection is now retained, and new and removed files are found when refreshing.
  * A new git-cola-completion.bash completion script is provided in the contrib/ directory. It must be used alongside Git’s completion script. Source it from your ~/.bashrc (or ~/.zshrc, etc) after sourcing the git-completion.bash script and you will have command-line completion support for the git cola and git dag sub-commands.
  * The “checkout” dialog now offers completion for remote branches and other git refs. This makes it easier to checkout remote branches in a detached head state. Additionally, the checkout dialog also offers completion for remote branches that have not yet been checked out, which makes it easier to create a local tracking branch by just completing for that potential name.
  https://github.com/git-cola/git-cola/issues/390
  * The “create branch” and “create tag” dialogs now save and restore their window settings.
  * The “status” widget can now be configured to use a bold font with a darker background for the header items.
  https://github.com/git-cola/git-cola/pull/506
  * The “status” widget now remembers its horizontol scrollbar position across updates. This is helpful when working on projects with long paths.
  https://github.com/git-cola/git-cola/issues/494
- Fixes
  * When using Git for Windows, a git window would appear when running Windows 8. We now pass additional flags to subprocess.Popen to prevent a git window from appearing.
  https://github.com/git-cola/git-cola/issues/477
  https://github.com/git-cola/git-cola/pull/486
  * Launching difftool with .PY in $PATHEXT on Windows was fixed.
  https://github.com/git-cola/git-cola/issues/492
  * Creating a local branch tracking a remote branch that contains slashes in its name is now properly handled.
  https://github.com/git-cola/git-cola/issues/496
  * The “Browse Other Branch” feature was broken by Python3, and is now fixed.
  https://github.com/git-cola/git-cola/issues/501
  * We now avoid long for better Python3 compatibility.
  https://github.com/git-cola/git-cola/issues/502
  * We now use Git’s default merge message when merging branches.
  https://github.com/git-cola/git-cola/issues/508
  * Miscellaneous fixes
  https://github.com/git-cola/git-cola/pull/485
- Packaging
  * git-cola’s documentation no longer uses an intersphinx link mapping to docs.python.org. This fixes warnings when building rpms using koji, where network access is prevented.
  https://bugzilla.redhat.com/show_bug.cgi?id=1231812
* Mon Aug 10 2015 marcin.bajor@gmail.com
- Update to 2.3
- Usability, bells and whistles
  * The Interactive Rebase feature now works on Windows!
  https://github.com/git-cola/git-cola/issues/463
  * The diff editor now understands vim-style hjkl navigation hotkeys.
  https://github.com/git-cola/git-cola/issues/476
  * Alt-{j,k} navigation hotkeys were added to allow changing to the next/previous file from the diff and commit editors.
  * The Rename branch menu action is now disabled in empty repositories.
  https://github.com/git-cola/git-cola/pull/475
  https://github.com/git-cola/git-cola/issues/459
  * git cola now checks unmerged files for conflict markers before staging them. This feature can be disabled in the preferences.
  https://github.com/git-cola/git-cola/issues/464
  * git dag now remembers which commits were selected when refreshing so that it can restore the selection afterwards.
  https://github.com/git-cola/git-cola/issues/480
  * “Launch Editor”, “Launch Difftool”, “Stage/Unstage”, and “Move Up/Down” hotkeys now work when the commit message editor has focus.
  https://github.com/git-cola/git-cola/issues/453
  * The diff editor now supports the Ctrl+u hotkey for reverting diff hunks and selected lines.
  * The core.commentChar Git configuration value is now honored. Commit messages and rebase instruction sheets will now use the configured character for comments. This allows having commit messages that start with # when core.commentChar is configured to its non-default value.
  https://github.com/git-cola/git-cola/issues/446
- Fixes
  * Diff syntax highlighting was improved to handle more edge cases and false positives.
  https://github.com/git-cola/git-cola/pull/467
  * Setting commands in the interactive rebase editor was fixed.
  https://github.com/git-cola/git-cola/issues/472
  * git-cola no longer clobbers the Ctrl+Backspace text editing shortcut in the commit message editor.
  https://github.com/git-cola/git-cola/issues/453
  * The copy/paste clipboard now persists after git cola exits.
  https://github.com/git-cola/git-cola/issues/484
* Tue Jun 16 2015 marcin.bajor@gmail.com
- Update to 2.2.1
- Fixes
  * Fixed the “Sign off” feature in the commit message editor.
* Mon Jun 15 2015 marcin.bajor@gmail.com
- Update to 2.2
- Usability, bells and whistles
  * Double-click will now choose a commit in the “Select commit” dialog.
  * git cola has a feature that reads .git/MERGE_MSG and friends for the commit message when a merge is in-progress. Upon refresh, git cola will now detect when a merge has completed and reset the commit message back to its previous state. It is only reset if the editor contains a message that was read from the file and has not been manually edited by the user.
  * The commit message editor’s context menu now has a “Clear...” action for clearing the message across both the summary and description fields.
  * Traditional Chinese (Taiwan) translation updates.
  * The system theme’s icons are now used whereever possible.
  https://github.com/git-cola/git-cola/pull/458
- Fixes
  * The stash viewer now uses git show --no-ext-diff to avoid running user-configured diff tools.
  * git cola now uses the setsid() system call to ensure that the GIT_ASKPASS and SSH_ASKPASS helper programs are used when pushing changes using git. The askpass helpers will now be used even when git cola is launched from a terminal.
  The behavior without setsid() is that git cola can appear to hang while pushing changes. The hang happens when git prompts the user for a password using the terminal, but the user never sees the prompt. setsid() detaches the terminal, which ensures that the askpass helpers are used.
  https://github.com/git-cola/git-cola/issues/218
  https://github.com/git-cola/git-cola/issues/262
  https://github.com/git-cola/git-cola/issues/377
  * git dag‘s file list tool was updated to properly handle unicode paths.
  * gnome-terminal is no longer used by default when cola.terminal is unset. It is broken, as was detailed in #456.
  https://github.com/git-cola/git-cola/issues/456
  * The interactive rebase feature was not always setting $GIT_EDITOR to the value of gui.editor, thus there could be instances where rebase will seem to not stop, or hang, when performing “reword” actions.
  We now set the $GIT_EDITOR environment variable when performing the “Continue”, “Skip”, and “Edit Todo” rebase actions so that the correct editor is used during the rebase.
  https://github.com/git-cola/git-cola/issues/445
* Tue Mar 31 2015 marcin.bajor@gmail.com
- Update to 2.1.2
- Usability, bells and whistles
  * Updated zh_TW translations.
  * git cola rebase now defaults to @{upstream}, and generally uses the same CLI syntax as git rebase.
  * The commit message editor now allows you to bypass commit hooks by selecting the “Bypass Commit Hooks” option. This is equivalent to passing the –no-verify option to git commit.
  https://github.com/git-cola/git-cola/issues/357
  * We now prevent the “Delete Files” action from creating a dialog that does not fit on screen.
  https://github.com/git-cola/git-cola/issues/378
  * git xbase learned to edit rebase instruction sheets that contain exec commands.
  * The diff colors are now configurable. cola.color.{text,add,remove,header} can now be set with 6-digit hexadecimal colors. See the git cola manual <https://git-cola.readthedocs.org/en/latest/git-cola.html#configuration-variables>_ for more details.
  * Improved hotkey documentation.
- Fixes
  * git cola will now allow starting an interactive rebase with a dirty worktree when rebase.autostash is set.
  https://github.com/git-cola/git-cola/issues/360
* Sun Feb  8 2015 mailaender@opensuse.org
- update to 2.1.1
  * A new “Find files” widget was added, and can be activated by using the Ctrl+t or t hotkeys.
  * A new git cola find sub-command was added for finding files.
  * git cola now remembers the text cursor’s position when staging interactively with the keyboard. This makes it easier to use the keyboard arrows to select and stage lines.
  * The completion widgets will now select the top completion item when Enter or Return are pressed.
  * You can now refresh using F5 in addition to the existing Ctrl+R hotkey.
  * git cola now passes –no-abbrev-commit to git log to override having log.abbrevCommit = true set in .gitconfig.
* Sat Jan 17 2015 mailaender@opensuse.org
- update to 2.1.0
  * git dag now forwards all unknown arguments along to git log.
  * Line-by-line interactive staging was made more robust.
  * “Bookmarks” was renamed to “Favorites”.
  * Untracked files are now displayed using a unique icon.
  * Untracked files are now assumed to be utf-8 encoded.
  * inotify expects unicode paths on Python3.
  * git dag was triggering a traceback on Fedora when parsing Git logs.
- fix rpmlint warning about missing %%build
* Sun Jan  4 2015 mailaender@opensuse.org
- Recommend optional python-send2trash module
* Sun Nov 30 2014 marcin.bajor@gmail.com
- Usability, bells and whistles
  * git cola can now create GPG-signed commits and merges.
  https://github.com/git-cola/git-cola/issues/149
  See the documentation for details about setting up a GPG agent.
  * The status widget learned to copy relative paths when Ctrl+x is pressed.
  https://github.com/git-cola/git-cola/issues/358
  * Custom GUI actions can now define their own keyboard shortcuts by setting guitool.$name.shortcut to a string understood by Qt’s QAction::setShortcut() API, e.g. Alt+x.
  See http://qt-project.org/doc/qt-4.8/qkeysequence.html#QKeySequence-2 for more details about the supported values.
  * git cola learned to rename branches.
  https://github.com/git-cola/git-cola/pull/364
  https://github.com/git-cola/git-cola/issues/278
  * git dag now has a “Show history” context menu which can be used to filter history using the selected paths.
- Fixes
  * sphinxtogithub.py was fixed for Python3.
  https://github.com/git-cola/git-cola/pull/353
  * The commit that changed how we read remotes from git remote to parsing git config was reverted since it created problems for some users.
  * Fixed a crash when using the rebase edit feature.
  https://github.com/git-cola/git-cola/issues/351
  * Better drag-and-drop behavior when dropping into gnome-terminal.
  https://github.com/git-cola/git-cola/issues/373
- Packaging
  * The git-cola-folder-handler.desktop file handler was fixed to pass validation by desktop-file-validate.
  https://github.com/git-cola/git-cola/issues/356
  * The git.svg icon was renamed to git-cola.svg, and git cola was taught to prefer icons from the desktop theme when available.
* Wed Oct  1 2014 marcin.bajor@gmail.com
- Update to version 2.0.7
- Usability, bells and whistles
  * New hotkey: Shift+Ctrl+M merges branches.
  * New hotkey: Ctrl+R refreshes the DAG viewer.
  https://github.com/git-cola/git-cola/issue/347
- Fixes
  * We now use git config to parse the list of remotes instead of parsing the output of git remote, which is a Git porcelain and should not be used by scripts.
  * Avoid “C++ object has been deleted” errors from PyQt4.
  https://github.com/git-cola/git-cola/issue/346
- Packaging
  * The make install target now uses install instead of cp.
* Mon Sep  1 2014 marcin.bajor@gmail.com
- Update to version 2.0.6
- Usability, bells and whistles
  * Updated Brazillian Portuguese translation.
  * The status and browse widgets now allow drag-and-drop into external applications.
  https://github.com/git-cola/git-cola/issue/335
  * We now show a progress bar when cloning repositories.
  https://github.com/git-cola/git-cola/issue/312
  * The bookmarks widget was simplified to not need a separate dialog.
  https://github.com/git-cola/git-cola/issue/289
  * Updated Traditional Chinese translation.
  * We now display a warning when trying to rebase with uncommitted changes.
  https://github.com/git-cola/git-cola/issue/338
  * The status widget learned to filter paths. Shift+Ctrl+s toggles the filter widget.
  https://github.com/git-cola/git-cola/issues/337
  https://github.com/git-cola/git-cola/pull/339
  * The status widget learned to move files to the trash when the send2trash module is installed.
  https://github.com/git-cola/git-cola/issues/341
  * “Recent repositories” is now a dedicated widget.
  https://github.com/git-cola/git-cola/issues/342
  * New Spanish translation thanks to Pilar Molina Lopez.
  https://github.com/git-cola/git-cola/pull/344
- Fixes
  * Newly added remotes are now properly seen by the fetch/push/pull dialogs.
  https://github.com/git-cola/git-cola/issues/343
* Wed Jul 30 2014 marcin.bajor@gmail.com
- Update to version 2.0.5
- Usability, bells and whistles
  * New Brazillian Portuguese translation thanks to Vitor Lobo.
  * New Indonesian translation thanks to Samsul Ma’arif.
  * Updated Simplified Chinese translation thanks to Zhang Han.
  * Ctrl+Backspace is now a hotkey for “delete untracked files” in the status widget.
  * Fetch/Push/Pull dialogs now use the configured remote of the current branch by default.
  https://github.com/git-cola/git-cola/pull/324
- Fixes
  * We now use os.getcwd() on Python3.
  https://github.com/git-cola/git-cola/pull/316
  https://github.com/git-cola/git-cola/pull/326
  * The Ctrl+P hotkey was overloaded to both “push” and “cherry-pick”, so “cherry-pick” was moved to Shift+Ctrl+C.
  * Custom GUI tools with mixed-case names are now properly supported.
  * “Diff Region” is now referred to as “Diff Hunk” for consistency with common terminology from diff/patch tools.
  https://github.com/git-cola/git-cola/issues/328
  * git-cola’s test suite is now portable to MS Windows.
  https://github.com/git-cola/git-cola/pull/332
* Fri Jun 27 2014 marcin.bajor@gmail.com
- Update to version 2.0.4
- Usability, bells and whistles
  * We now handle the case when inotify add_watch() fails and display instructions on how to increase the number of watches.
  https://github.com/git-cola/git-cola/issues/263
  * New and improved zh_TW localization thanks to Ｖ字龍(Vdragon).
  https://github.com/git-cola/git-cola/pull/265
  https://github.com/git-cola/git-cola/pull/267
  https://github.com/git-cola/git-cola/pull/268
  https://github.com/git-cola/git-cola/issues/269
  https://github.com/git-cola/git-cola/pull/270
  https://github.com/git-cola/git-cola/pull/271
  https://github.com/git-cola/git-cola/pull/272
  * New hotkeys: Ctrl+f for fetch, Ctrl+p for push, and Ctrl-shift-p for pull.
  * The bookmarks widget’s context menu actions were made clearer.
  https://github.com/git-cola/git-cola/issues/281
  * The term “Staging Area” is used consistently in the UI to allow for better localization.
  https://github.com/git-cola/git-cola/issues/283
  * The “Section” term is now referred to as “Diff Region” in the UI.
  https://github.com/git-cola/git-cola/issues/297
  * he localization documentation related to the LANGUAGE environment variable was improved.
  https://github.com/git-cola/git-cola/pull/293
  * The “Actions” panel now contains tooltips for each button in case the button labels gets truncated by Qt.
  https://github.com/git-cola/git-cola/issues/292
  * Custom git config-defined actions can now be run in the background by setting guitool.<name>.background to true.
- Fixes
  * We now use bold fonts instead of SmallCaps to avoid artifacts on several configurations.
  * We now pickup user.email, cola.tabwidth, and similar settings when defined in /etc/gitconfig.
  https://github.com/git-cola/git-cola/issues/259
  * Better support for unicode paths when using inotify.
  https://bugzilla.redhat.com/show_bug.cgi?id=1104181
  * Unicode fixes for non-ascii locales.
  https://github.com/git-cola/git-cola/issues/266
  https://github.com/git-cola/git-cola/issues/273
  https://github.com/git-cola/git-cola/issues/276
  https://github.com/git-cola/git-cola/issues/282
  https://github.com/git-cola/git-cola/issues/298
  https://github.com/git-cola/git-cola/issues/302
  https://github.com/git-cola/git-cola/issues/303
  https://github.com/git-cola/git-cola/issues/305
  * Viewing history from the file browser was fixed for Python3.
  https://github.com/git-cola/git-cola/issues/274
  * setup.py was fixed to install the *.rst documentation.
  https://github.com/git-cola/git-cola/issues/279
  * Patch export was fixed for Python3.
  https://github.com/git-cola/git-cola/issues/290
  * Fixed adding a bookmark with trailing slashes.
  https://github.com/git-cola/git-cola/pull/295
  * The default git dag layout is now setup so that its widgets can be freely resized on Linux.
  https://github.com/git-cola/git-cola/issues/299
  * Invalid tag names are now reported when creating tags.
  https://github.com/git-cola/git-cola/pull/296
* Mon May 26 2014 marcin.bajor@gmail.com
- Update to version 2.0.3
- Usability, bells and whistles
  * git cola no longer prompts after successfully creating a new branch.
  https://github.com/git-cola/git-cola/pull/251
  * Hitting enter on simple dialogs now accepts them.
  https://github.com/git-cola/git-cola/pull/255
- Fixes
  * git dag no longer relies on sys.maxint, which is not available in Python3.
  https://github.com/git-cola/git-cola/issues/249
  * Python3-related fixes.
  https://github.com/git-cola/git-cola/pull/254
  * Python3-on-Windows-related fixes.
  https://github.com/git-cola/git-cola/pull/250
  https://github.com/git-cola/git-cola/pull/252
  https://github.com/git-cola/git-cola/pull/253
  * Switching repositories using the bookmarks widget was not refreshing the inotify watcher.
  https://github.com/git-cola/git-cola/pull/256
  * Special commit messages trailers (e.g. “Acked-by:”) are now special-cased to fix word wrapping lines that start with “foo:”.
  https://github.com/git-cola/git-cola/issues/257
* Sun Apr 20 2014 marcin.bajor@gmail.com
- Update to version 2.0.2
- Usability, bells and whistles
  * Better inotify support for file creation and deletion.
  https://github.com/git-cola/git-cola/issues/240
  * git cola now supports the X11 Session Management Protocol and remembers its state across logout/reboot.
  https://github.com/git-cola/git-cola/issues/164
  * git cola has a new icon.
  https://github.com/git-cola/git-cola/issues/190
- Packaging
  * Building the documentation no longer requires asciidoc. We now use Sphinx for building html documentation and man pages.
- Fixes
  * Reworked the git-dag gravatar icon code to avoid a unicode error in Python 2.
  * Commit message line-wrapping was made to better match the GUI editor.
  https://github.com/git-cola/git-cola/issues/242
  * Better support for Python3 on Windows
  https://github.com/git-cola/git-cola/issues/246
- Packaging
  * git-cola no longer depends on Asciidoc for building its documentation and man-pages. We now depend on [Sphinx](http://sphinx-doc.org/) only.
* Sun Mar 16 2014 marcin.bajor@gmail.com
- Update to version 2.0.1
- Usability, bells and whistles
  * Some context menu actions are now hidden when selected files do not exist.
  https://github.com/git-cola/git-cola/issues/238
- Fixes
  * The build-git-cola.sh contrib script was improved.
  https://github.com/git-cola/git-cola/pull/235
  * Non-ascii worktrees work properly again.
  https://github.com/git-cola/git-cola/issues/234
  * The browser now guards itself against missing files.
  https://bugzilla.redhat.com/show_bug.cgi?id=1071378
  * Saving widget state now works under Python3.
  https://github.com/git-cola/git-cola/pull/236
* Mon Feb 24 2014 marcin.bajor@gmail.com
- Update to version 2.0.0
- Portability
  * git-cola now runs on Python 3 thanks to Virgil Dupras.
  https://github.com/git-cola/git-cola/pull/233
  * Python 2.6, 2.7, and 3.2+ are now supported. Python 2.5 is no longer supported.
- Fixes
  * i18n test fixes thanks to Virgil Dupras.
  https://github.com/git-cola/git-cola/pull/231
  * git-cola.app build fixes thanks to Maicon D. Filippsen.
  https://github.com/git-cola/git-cola/pull/230
  * Lots of pylint improvements thanks to Alex Chernetz.
  https://github.com/git-cola/git-cola/pull/229
* Fri Jan 31 2014 marcin.bajor@gmail.com
- Update to version 1.9.4
- Usability, bells and whistles
  * The new Bookmarks tool makes it really easy to switch between repositories.
  * There is now a dedicated dialog for applying patches. See the File -> Apply Patches menu item.
  https://github.com/git-cola/git-cola/issues/215
  * A new git cola am sub-command was added for applying patches.
- Fixes
  * Fixed a typo that caused inotify events to be silently ignored.
  * Fixed the sys.path setup for Mac OS X (Homebrew).
  https://github.com/git-cola/git-cola/issues/221
  * Lots of pylint fixes thanks to Alex Chernetz.
* Wed Dec 11 2013 marcin.bajor@gmail.com
- Update to version 1.9.3
- Usability, bells and whistles
  * git cola –amend now starts the editor in amend mode.
  https://github.com/git-cola/git-cola/issues/187
  * Multiple lines of text can now be pasted into the summary field. All text beyond the first newline will be automatically moved to the extended description field.
  https://github.com/git-cola/git-cola/issues/212
- Fixes
  * Stray whitespace in .git files is now ignored.
  https://github.com/git-cola/git-cola/issues/213
  * Fix “known incorrect sRGB profile” in staged-item.png.
  http://comments.gmane.org/gmane.linux.gentoo.devel/85066
* Fri Nov 29 2013 marcin.bajor@gmail.com
- Update to version 1.9.2
- Fixes
  * Fix a traceback when git push fails.
  https://bugzilla.redhat.com/show_bug.cgi?id=1034778
- Packaging
  * Most of the git-cola sub-packages have been removed. The only remaining packages are cola, cola.models, and cola.widgets.
  * The translation file for Simplified Chinese was renamed to zh_CN.po.
  https://github.com/git-cola/git-cola/issues/209
* Sun Oct 20 2013 mailaender@opensuse.org
- Update to version 1.9.1
  * git cola version –brief now prints the brief version number.
  * Resurrected the “make dist” target, for those that prefer to create their own tarballs.
  * Fixed the typo that broke the preferences dialog.
- Changes from 1.9.0
  * We now ship a full-featured interactive git rebase editor. The rebase todo file is edited using the git xbase script which is provided at $prefix/share/git-cola/bin/git-xbase. This script can be used standalone by setting the $GIT_SEQUENCE_EDITOR before running git rebase –interactive.
  * Fixup commit messages can now be loaded from the commit message editor.
  * Tool widgets can be locked in place by using the “Tools/Lock Layout” menu action.
  * You can now push to several remotes simultaneously by selecting multiple remotes in the “Push” dialog.
  * The grep tool learned to search using three different modes: basic regular expressions (default), extended regular expressions, and fixed strings.
  * git cola now depends on the argparse Python module. This module is part of the stdlib in Python 2.7 and must be installed separately when using Python 2.6 and below.
  * Support unicode in the output from fetch, push, and pull.
* Fri Sep 27 2013 marcin.bajor@gmail.com
- Update to version 1.8.5
- Usability, bells and whistles
  * We now detect the editor or history browser are misconfigured.
  http://github.com/git-cola/git-cola/issues/197
  https://bugzilla.redhat.com/show_bug.cgi?id=886826
  * Display of untracked files can be disabled from the Preferences dialog or by setting the gui.displayuntracked configuration variable to false.
  http://thread.gmane.org/gmane.comp.version-control.git/232683
- Fixes
  * Unicode stash names are now supported
  http://github.com/git-cola/git-cola/issues/198
  * The diffs produced when reverting workspace changes were made more robust.
* Thu Aug 29 2013 marcin.bajor@gmail.com
- Update to version 1.8.4
- Usability, bells and whistles
  * Brand new German translation thanks to Sven Claussner.
  * The “File” menu now provides a “New Repository...” menu action.
  * git dag now uses a dock-widget interface so that its widgets can be layed-out and arranged. Customizations are saved and restored the next time git dag is launched.
  * git dag now has a “Zoom Best Fit” button next alongside the “Zoom In” and “Zoom Out” buttons.
  * Ctrl+L now focuses the “Search” field in the git dag tool.
  * Right-clicking in the “diff” viewer now updates the cursor position before performing actions, which makes it much easier to click around and selectively stage sections. Previously, the current cursor position was used which meant that it required two clicks (left-click to update the position followed by right-click to get the context menu) for the desired section to be used. This is now a single right-click operation.
  * The Ctrl+D “Launch Diff Tool” action learned to automatically choose between git difftool and git mergetool. If the file is unmerged then we automatically launch git mergetool on the path, otherwise we use git difftool. We do this because git difftool is not intended to be used on unmerged paths. Automatically using git mergetool when appropriate is the most intuitive and muscle-memory-friendly thing to do.
  * You can now right-click on folders in your standard file browser and choose “Open With -> Git Cola” (Linux-only).
- Fixes
  * Python 2.6 on Mac OS X Snow Leopard does not provide a namedtuple at sys.version_info. We now avoid using that variable for better portability.
  * We now read the user’s Git configuration from ~/.config/git/config if that file is available, otherwise we use the traditional ~/.gitconfig path, just like Git itself.
  * Some edge cases were fixed when applying partial/selected diffs.
  * The diff viewer is now properly cleared when refreshing. http://github.com/git-cola/git-cola/issues/194
* Tue May  7 2013 marcin.bajor@gmail.com
- Update to version 1.8.3
- Usability, bells and whistles
  * The diff viewer now has an “Options” menu which can be used to set “git diff” options. This can be used to ignore whitespace changes or to show a change with its surrounding function as context.
  http://github.com/git-cola/git-cola/issues/150
  * git cola now remembers your commit message and will restore it when git cola is restarted.
  https://github.com/git-cola/git-cola/pull/175
  * Ctrl+M can now be used to toggle the “Amend last commit” checkbox in the commit message editor.
  https://github.com/git-cola/git-cola/pull/161
  * Deleting remote branches can now be done from the “Branch” menu.
  https://github.com/git-cola/git-cola/issues/152
  * The commit message editor now has a built-in spell checker.
- Fixes
  * We now avoid invoking external diffs when showing diffstats.
  https://github.com/git-cola/git-cola/pull/163
  * The Status tool learned to reselect files when refreshing.
  https://github.com/git-cola/git-cola/issues/165
  * git cola now remembers whether it has been maximized and will restore the maximized state when git cola is restarted.
  https://github.com/git-cola/git-cola/issues/172
  * Performance is now vastly improved when staging hundreds or thousands of files.
  * git cola was not correctly saving repo-specific configuration.
  https://github.com/git-cola/git-cola/issues/174
  * Fix a UnicodeDecode in sphinxtogithub when building from source.-
* Wed Feb 27 2013 marcin.bajor@gmail.com
- Update to version 1.8.2
- Usability, bells and whistles
  * We now automatically remove missing repositories from the “Select Repository” dialog.
  http://github.com/git-cola/git-cola/issues/145
  * A new git cola diff sub-command was added for diffing changed files.
- Fixes
  * The inotify auto-refresh feature makes it difficult to select text in the “diff” editor when files are being continually modified by another process. The auto-refresh causes it to lose the currently selected text, which is not wanted. We now avoid this problem by saving and restoring the selection when refreshing the editor.
  http://github.com/git-cola/git-cola/issues/155
  * More strings have been marked for l10n.
  http://github.com/git-cola/git-cola/issues/157
  * Fixed the Alt+D Diffstat shortcut.
  http://github.com/git-cola/git-cola/issues/159
- Fixes
  * Better error handling when cloning repositories.
  We were not handling the case where a git URL has no basename, e.g. https://git.example.com/. git cola originally rejected these URLs instead of allowing users to clone them. It now allows these URLs when they point to valid git repositories.
  Additionally, git cola learned to echo the errors reported by git clone when it fails.
  http://github.com/git-cola/git-cola/issues/156
* Sat Dec  8 2012 marcin.bajor@gmail.com
- Update to version 1.8.1
- Usability, bells and whistles
  * git-dag got a big visual upgrade.
  * Ctrl+G now launches the “Grep” tool.
  * Ctrl+D launches difftool and Ctrl+E launches your editor when in the diff panel.
  * git-cola can now be told to use an alternative language. For example, if the native language is German and we want git-cola to use English then we can create a ~/.config/git-cola/language file with “en” as its contents:
  $ echo en >~/.config/git-cola/language
  http://github.com/git-cola/git-cola/issues/140
  * A new git cola merge sub-command was added for merging branches.
  * Less blocking in the main UI
- Fixes
  * Autocomplete issues on KDE
  http://github.com/git-cola/git-cola/issues/144
- The “recently opened repositories” startup dialog did not display itself in the absence of bookmarks.
  http://github.com/git-cola/git-cola/issues/139
* Thu Aug 23 2012 marcin.bajor@gmail.com
- Update to version 1.8.0
- Usability, bells and whistles
  * git cola learned to honor .gitattributes when showing and interactively applying diffs. This makes it possible to store files in git using a non-utf-8 encoding and git cola will properly accept them. This must be enabled by settings cola.fileattributes to true, as it incurs a small performance penalt
  http://github.com/git-cola/git-cola/issues/closed#issue/96
  * git cola now wraps commit messages at 72 columns automatically. This is configurable using the cola.linebreak variable to enable/disable the feature, and cola.textwidth to configure the limit.
  http://github.com/git-cola/git-cola/issues/closed#issue/133
  * A new “Open Recent” sub-menu was added to the “File” menu. This makes it easy to open a recently-edited repository.
  http://github.com/git-cola/git-cola/issues/closed#issue/135
  * We now show a preview for untracked files when they are clicked using the Status tool.
  * A new “Open Using Default Application” action was added to the Status tool. It is activated using either Spacebar or through the context menu. This action uses xdg-open on Linux and open on Mac OS X.
  * A new “Open Parent Directory” action was added to the Status tool. It is activated using either Shift+Spacebar or through the context menu.
  * git dag learned to honor the log.date git configuration variable. This makes the date display follow whatever format the user has configured.
  * A new git cola config sub-command was added for quickly tweaking git cola‘s git configuration settings.
  * Some small usability tweaks – some user confirmation prompts were defaulting to “Cancel” when they should have been defaulting to the affirmative option instead.
- Fixes
  * Properly handle arbitrarily-named branches.
  * We went back to launching git mergetool using an xterm. The reason is that there are a couple of places where git mergetool requires a terminal for user interaction not covered by –no-prompt.
  * We now properly handle an edge case when applying short diffs at the start of a file
* Fri May 11 2012 marcin.bajor@gmail.com
- Update to version 1.7.7
- Usability, bells and whistles
  * New and improved grep mode lets you instantly find and edit files.
  * New git cola grep standalone mode.
  * Support for passing arguments to the configured editors, e.g. gvim -p This makes it possible to select multiple files in the status window and use Ctrl-e to edit them all at once.
  * Remote operations now prompt on errors only.
  * The Tab key now jumps to the extended description when editing the summary.
  * More shortcut key labels and misc. UX improvements.
- Fixes
  * Selecting an item no longer copies its filename to the copy/paste buffer. Ctrl-c or the “Copy” context-menu action can be used instead.
  * The repository monitoring feature on Windows learned to ignore changes within the ”.git” directory. Thanks to Andreas Sommer.-
* Sat Mar 24 2012 marcin.bajor@gmail.com
- Update to version 1.7.6
- git dag learned to color-code branchy edges. The edge colors change when a new branch is detected, which makes the history much easier to follow. A huge thanks to Uri Okrent for making it happen.
- New GUI for editing remote repositories.
- New git cola archive and git cola remote sub-commands.
- git cola browser learned an ‘Untrack’ command.
- The diff editor learned to staged/unstaged while amending.
- The status tool can now scroll horizontally.
- New git repositories can be created by clicking ‘New’ on the git cola –prompt startup screen.
* Thu Jan 26 2012 marcin.bajor@gmail.com
- Update to version 1.7.5
- Auto-completion was added to more tools.
- git-dag is easier to use on smaller displays – the author field elides its text which allows for a more compact display.
- Selected commits in git-dag were made more prominent and easier to see.
- ‘Create Branch’ learned to fetch remote branches and uses a background thread to do so.
- User-configured GUI tools are listed alphabetically in the ‘Actions’ menu.
- The ‘Pull’ dialog remembers the value of the ‘Rebase’ checkbox between invocations.
* Sun Jan  8 2012 marcin.bajor@gmail.com
- Update to version 1.7.4.1
- Detect Homebrew so that OS X users do not need to set PYTHONPATH.
- git-dag can export patches again.
* Thu Jan  5 2012 marcin.bajor@gmail.com
- Update to version 1.7.4
- The ‘Classic’ tool was renamed to ‘Browser’ and learned to limit history to the current branch.
- git-dag learned about gravatar and uses it to show images for commit authors.
- git-dag learned to use OpenGL for rendering resulting in much faster rendering.
- More dialogs learned vim-style keyboard shortcuts.
- The commit message editor learned better arrow key navigatio
* Wed Dec 28 2011 marcin.bajor@gmail.com
- Update to version 1.7.3
- git-cola learned a few new sub commands:
  * git cola dag
  * git cola branch
  * git cola search
- Return in the summary field jumps to the extended description.
- Ctrl+Return is now a shortcut for ‘Commit’.
- Better French translation for ‘Sign-off’.
- The ‘Search’ widget now has a much simpler and streamlined user interface.
- vim-style h,j,k,l navigation shortcuts were added to the DAG widget.
- git-dag no longer prompts for files when diffing commits if the text field contains paths.
- General user interface and performance improvements.
* Tue Dec  6 2011 marcin.bajor@gmail.com
- Update to version 1.7.2
- git-cola can now launch sub commands, e.g.:
  * git cola classic
  * git cola stash
  * git cola fetch
  * git cola push
  * git cola pull
  * git cola tag
- git-dag is more responsive when gathering tab-completions.
- Keyboard shortcuts are displayed when the ‘?’ key is pressed.
- Various keyboard shortcuts were added for improved usability.
- The status widget now lists unmerged files before modified files.
- vim-style h,j,k,l navigation shortcuts were added to the status widget.
- A ‘Recently Modified Files...’ tool was added.
- Tools can now be hidden with Alt + # (where # is a keyboard number) and focused with Shift + Alt + #.
- The syntax highlighting colors for diffs was made less intrusive.
- The commit message editor was redesigned to have a more compact and keyboard-convenient user interface.
- Keyboard shortcuts for adding a Signed-off-by (Ctrl + i) and creating a commit (Ctrl + m) were added.
- The status widget was adjusted to use less screen real-estate.
* Sat Nov 26 2011 marcin.bajor@gmail.com
- Update to version 1.7.1.1
- Fixes
  * Further enhanced the staging/unstaging behavior in the status widget.
  * Unmerged files are no longer listed as modified.
* Thu Nov  3 2011 marcin.bajor@gmail.com
- Update to version 1.7.0
* Sun Oct 23 2011 marcin.bajor@gmail.com
- Update to version 1.4.5.3
